@@ -244,6 +244,9 @@ gps_m_size_value_changed (GtkAdjustment *adj, GnomePaperSelector *ps)
 	ps->mt = mt;
 	ps->mb = mb;
 
+	gpa_paper_preview_item_set_logical_margins 
+		(GNOME_CANVAS_ITEM (GNOME_PAPER_PREVIEW (ps->preview)->item),
+		 ml, mr, mt, mb);
 }
 
 static void
@@ -583,6 +586,7 @@ gnome_paper_selector_construct (GnomePaperSelector *ps)
 	ps->w = config_width;
 	wa = gtk_adjustment_new (config_width, 0.0001, 10000, 1, 10, 10);
 	ps->pw = gtk_spin_button_new (GTK_ADJUSTMENT (wa), 1, 2);
+	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (ps->pw), TRUE);
 	gtk_widget_show (ps->pw);
 	gtk_table_attach_defaults (GTK_TABLE (t), ps->pw, 2, 3, 1, 2);
 	gtk_label_set_mnemonic_widget ((GtkLabel *) l, ps->pw);
@@ -600,6 +604,7 @@ gnome_paper_selector_construct (GnomePaperSelector *ps)
 	ps->h = config_height;
 	ha = gtk_adjustment_new (config_height, 0.0001, 10000, 1, 10, 10);
 	ps->ph = gtk_spin_button_new (GTK_ADJUSTMENT (ha), 1, 2);
+	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (ps->ph), TRUE);
 	gtk_widget_show (ps->ph);
 	gtk_table_attach_defaults (GTK_TABLE (t), ps->ph, 2, 3, 2, 3);
 	gtk_label_set_mnemonic_widget ((GtkLabel *) l, ps->ph);
